#
# spec file for package libdbi-drivers
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

%if 0%{?suse_version} == 1110
%define build_freetds 0
%else 
%define build_freetds 1
%endif

Name:           libdbi-drivers
Version:        0.9.0.g53
Release:        4.2
Summary:        Database drivers for libdbi
License:        LGPL-2.1+
Group:          Productivity/Databases/Servers
URL:            http://libdbi-drivers.sf.net/
#Source:        http://downloads.sf.net/libdbi-drivers/%name-%version.tar.gz
Source:		%name-%version.tar.xz
Patch1:         0001-build-adjust-configure-for-postgresql-10-11.patch
Patch2:         0001-build-resolve-build-failure-due-to-mismatching-types.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  gettext
%if %build_freetds
BuildRequires:  freetds-devel
%endif
BuildRequires:  libdbi-devel >= 0.9.0.g30
BuildRequires:  libtool
BuildRequires:  mysql-devel
BuildRequires:  openjade
BuildRequires:  postgresql-devel
BuildRequires:  sqlite3-devel
BuildRequires:  xz
%define build_doc 0
%if %build_doc
# Only needed when doc is not already prebuilt
BuildRequires:  docbook-dsssl-stylesheets
BuildRequires:  openjade
BuildRequires:  texlive-collection-fontsrecommended
BuildRequires:  texlive-jadetex
BuildRequires:  texlive-pdftex-bin
%endif

%description
libdbi implements a database-independent abstraction layer in C,
similar to the DBI/DBD layer in Perl. Drivers are distributed
separately from the library itself.

%package dbd-freetds
Summary:        FreeTDS driver for libdbi
Group:          System/Libraries

%description dbd-freetds
This driver provides connectivity to FreeTDS database servers
through the libdbi database independent abstraction layer. Switching
a program's driver does not require recompilation or rewriting source
code.

%package dbd-mysql
Summary:        MySQL driver for libdbi
Group:          System/Libraries

%description dbd-mysql
This driver provides connectivity to MySQL database servers through
the libdbi database independent abstraction layer. Switching a
program's driver does not require recompilation or rewriting source
code.

%package dbd-pgsql
Summary:        PostgreSQL driver for libdbi
Group:          System/Libraries

%description dbd-pgsql
This driver provides connectivity to PostgreSQL database servers
through the libdbi database independent abstraction layer. Switching
a program's driver does not require recompilation or rewriting source
code.

%package dbd-sqlite3
Summary:        SQLite3 driver for libdbi
Group:          System/Libraries

%description dbd-sqlite3
This driver provides connectivity to SQLite 3.x database servers through the
libdbi database independent abstraction layer. Switching a program's driver
does not require recompilation or rewriting source code.

%prep
%autosetup -p1
chmod a-x COPYING

# Fake the __DATE__ so we do not needelessly rebuild
FAKE_BUILDDATE=$(LC_ALL=C date -u -r %_sourcedir/%name.changes '+%%b %%e %%Y')
sed -i "s/__DATE__/\"$FAKE_BUILDDATE\"/" drivers/*/*.c

%build
if [ ! -e configure ]; then
	autoreconf -fi
fi
%configure		\
%if %build_freetds
	--with-freetds				\
%endif
	--with-mysql 				\
	--with-pgsql 				\
	--with-sqlite3      \
	--with-dbi-incdir="%_includedir/dbi"	\
	--with-dbi-libdir="%_libdir"		\
	--disable-static			\
	--docdir="%_docdir/%name" --disable-docs
%make_build

%install
%make_install
find "%buildroot" -type f -name "*.la" -delete

%check
make check || :

%if %build_freetds
%files dbd-freetds
%license COPYING
%dir %_libdir/dbd
%_libdir/dbd/libdbdfreetds.so
%endif

%files dbd-mysql
%license COPYING
%dir %_libdir/dbd
%_libdir/dbd/libdbdmysql.so

%files dbd-pgsql
%license COPYING
%dir %_libdir/dbd
%_libdir/dbd/libdbdpgsql.so

%files dbd-sqlite3
%license COPYING
%dir %_libdir/dbd
%_libdir/dbd/libdbdsqlite3.so

%changelog
* Sat Nov  2 2024 Jan Engelhardt <jengelh@inai.de>
- Add 0001-build-resolve-build-failure-due-to-mismatching-types.patch
* Thu Mar 21 2019 Jan Engelhardt <jengelh@inai.de>
- Remove configure.ac.patch (was only applied for 1110 anyway)
- Add 0001-build-adjust-configure-for-postgresql-10-11.patch
* Mon Mar 19 2018 mpluskal@suse.com
- Drop support for sqlite2 (see boo#1085790)
* Fri Jan 27 2017 jengelh@inai.de
- Update to new git snapshot 0.9.0.g53
  * Resolve build error with freetds 1.0
* Thu Feb  4 2016 christof.hanke@rzg.mpg.de
- allow building on SLES11-SP3 by removing freetds dependency
  and unknown configure option "serial-tests" for SLES11;
  add configure.ac.patch
* Tue Nov 11 2014 jengelh@inai.de
- Update to new git snapshot 0.9.0+git51
  * Fixed an out-of-bounds access in dbd_mysql due to bad type
  punning. [boo#904873]
* Mon Jul  7 2014 jengelh@inai.de
- Update to new git snapshot 0.9.0+git46
  * Support automatic reconnect under MySQL
  * Support character set retention across autoreconnect cycles
  * Have drivers use the new DBI_TYPE_XDECIMAL type
- Enable building FreeTDS plugin
* Thu May  8 2014 jengelh@inai.de
- Update to new git snapshot 0.9.0+git42
  * dbd_mysql, dbd_msql: avoid NULL dereference
* Thu Apr 17 2014 jengelh@inai.de
- Update to new git snapshot 0.9.0+git40
  * Support the new datetimex API from libdbi-0.9.0+git21
  * dbd_sqlite3: resolve a stack buffer overflow
- Remove sqlite3.diff, badcode.diff, libdl.diff: merged upstream
* Thu Feb  6 2014 fcrozat@suse.com
- Add COPYING to generated package.
* Wed Sep 11 2013 jengelh@inai.de
- Added libdl.diff (successfully link testsuite) and run testsuite
  as far as possible
* Wed Sep 11 2013 tchvatal@suse.com
- Remove tests code to have this not fail on rpm checks.
- Do not put __DATE__ into resulting binaries to avoid needless
  rebuilds.
* Sun Sep  8 2013 jengelh@inai.de
- Update to new upstream release 0.9.0
  * the pgsql driver now supports features specific to PostgreSQL 9
  and later
  * drivers now support transactions and savepoints if the underlying
  database engines do
- Added badcode.diff, sqlite3.diff to resolve build failures
* Thu Sep 27 2012 idonmez@suse.com
- Fix libdbi dependencies
* Wed Feb  1 2012 jengelh@medozas.de
- Remove redundant tags/sections per specfile guideline suggestions
- Parallel building using %%_smp_mflags
* Thu Jan 12 2012 coolo@suse.com
- change license to be in spdx.org format
* Tue Feb 22 2011 coolo@novell.com
- remove explicit (and wrong) libmysql require
* Wed Dec 15 2010 meissner@suse.de
- spec file cleanup
- disabled static driver libs
- pass in RPM_OPT_FLAGS
* Wed Dec 15 2010 meissner@suse.de
- split off from libdbi
